@@ -285,9 +285,8 @@ def snowflake_stage_load_copy_remove(
     table_path: str,
     engine: Engine,
     type: str = "json",
-    on_error: str = "skip_file",
+    on_error: str = "abort_statement",
     file_format_options: str = "",
-    remove_logs: bool = False,
 ) -> None:
     """
     Upload file to stage, copy to table, remove file from stage on Snowflake
@@ -314,11 +313,7 @@ def snowflake_stage_load_copy_remove(
 
         remove_query = f"remove @{stage} pattern='{file_pattern}'"
 
-    if remove_logs:
-        # Only read critical logs.
-        logging.basicConfig(stream=sys.stdout, level=logging.CRITICAL)
-    else:
-        logging.basicConfig(stream=sys.stdout, level=20)
+    logging.basicConfig(stream=sys.stdout, level=20)
 
     try:
         connection = engine.connect()
